@@ -332,6 +332,8 @@ class DataTransformer(MPTTModel):
             models.Index(fields=['id','accessory']),
         ]
 
+    class MPTTMeta:
+        order_insertion_by = ['id']
 
 
 class DataTransformerConstants(models.Model):
